=== modified file 'handler/Handler.xml'
--- handler/Handler.xml	2015-01-19 21:14:26 +0000
+++ handler/Handler.xml	2015-06-24 17:27:35 +0000
@@ -118,9 +118,9 @@
             ]]></dox:d>
             <arg name="result" type="as" direction="out"/>
         </method>
-        <method name="IsConnected">
+        <method name="IsReady">
             <dox:d><![CDATA[
-                Returns true if there is at least one account connected
+                Returns true if TelepathyHelper is ready
             ]]></dox:d>
             <arg name="result" type="b" direction="out"/>
         </method>

=== modified file 'handler/handlerdbus.cpp'
--- handler/handlerdbus.cpp	2015-01-19 21:14:26 +0000
+++ handler/handlerdbus.cpp	2015-06-24 17:27:35 +0000
@@ -65,9 +65,9 @@
     return TelepathyHelper::instance()->accountIds();
 }
 
-bool HandlerDBus::IsConnected()
+bool HandlerDBus::IsReady()
 {
-    return TelepathyHelper::instance()->connected();
+    return TelepathyHelper::instance()->ready();
 }
 
 bool HandlerDBus::callIndicatorVisible() const

=== modified file 'handler/handlerdbus.h'
--- handler/handlerdbus.h	2015-01-19 21:14:26 +0000
+++ handler/handlerdbus.h	2015-06-24 17:27:35 +0000
@@ -47,7 +47,7 @@
     QVariantMap GetCallProperties(const QString &objectPath);
     bool HasCalls();
     QStringList AccountIds();
-    bool IsConnected();
+    bool IsReady();
     bool callIndicatorVisible() const;
     void setCallIndicatorVisible(bool visible);
 

=== modified file 'handler/texthandler.cpp'
--- handler/texthandler.cpp	2015-06-05 20:36:01 +0000
+++ handler/texthandler.cpp	2015-06-24 17:27:35 +0000
@@ -58,13 +58,13 @@
 
     // track when the account becomes available
     connect(TelepathyHelper::instance(),
-            SIGNAL(connectedChanged()),
+            SIGNAL(setupReady()),
             SLOT(onConnectedChanged()));
 }
 
 void TextHandler::onConnectedChanged()
 {
-    if (!TelepathyHelper::instance()->connected()) {
+    if (!TelepathyHelper::instance()->ready()) {
         return;
     }
 

=== modified file 'indicator/voicemailindicator.cpp'
--- indicator/voicemailindicator.cpp	2015-02-06 20:44:14 +0000
+++ indicator/voicemailindicator.cpp	2015-06-24 17:27:35 +0000
@@ -31,8 +31,8 @@
 : QObject(parent),
   mConnection(QDBusConnection::sessionBus())
 {
-    connect(TelepathyHelper::instance(), SIGNAL(accountReady()), SLOT(onAccountReady()));
-    connect(TelepathyHelper::instance(), SIGNAL(connectedChanged()), SLOT(onAccountReady()));
+    connect(TelepathyHelper::instance(), SIGNAL(setupReady()), SLOT(onAccountReady()));
+    connect(TelepathyHelper::instance(), SIGNAL(accountsChanged()), SLOT(onAccountReady()));
 }
 
 void VoiceMailIndicator::onAccountReady()

=== modified file 'libtelephonyservice/accountentry.cpp'
--- libtelephonyservice/accountentry.cpp	2015-06-11 16:54:33 +0000
+++ libtelephonyservice/accountentry.cpp	2015-06-24 17:27:35 +0000
@@ -24,9 +24,12 @@
 #include "accountentry.h"
 #include "protocolmanager.h"
 
+Q_DECLARE_METATYPE(Tp::ConnectionPtr);
+
 AccountEntry::AccountEntry(const Tp::AccountPtr &account, QObject *parent) :
     QObject(parent), mAccount(account), mReady(false), mProtocol(0)
 {
+    qRegisterMetaType<Tp::ConnectionPtr>();
     initialize();
 }
 
@@ -99,8 +102,7 @@
 bool AccountEntry::connected() const
 {
     return !mAccount.isNull() && !mAccount->connection().isNull() &&
-           !mAccount->connection()->selfContact().isNull() &&
-            mAccount->connection()->selfContact()->presence().type() == Tp::ConnectionPresenceTypeAvailable;
+           mAccount->connection()->status() == Tp::ConnectionStatusConnected;
 }
 
 Tp::AccountPtr AccountEntry::account() const
@@ -145,59 +147,25 @@
     connect(mAccount.data(),
             SIGNAL(displayNameChanged(QString)),
             SIGNAL(displayNameChanged()));
-    \
-    // watch for account state and connection changes
-    connect(mAccount.data(), &Tp::Account::stateChanged, [this](bool enabled) {
-        if (!enabled) {
-            ensureEnabled();
-        }
-    });
 
     connect(mAccount.data(),
             SIGNAL(connectionChanged(Tp::ConnectionPtr)),
-            SLOT(onConnectionChanged()));
+            SLOT(onConnectionChanged(Tp::ConnectionPtr)));
+
+    connect(mAccount.data(),
+            SIGNAL(connectionStatusChanged(Tp::ConnectionStatus)),
+            SIGNAL(connectionStatusChanged(Tp::ConnectionStatus)));
 
     connect(this,
             SIGNAL(connectedChanged()),
             SIGNAL(activeChanged()));
 
-    // emit the statusChanged and statusMessageChanged signals together with the connectedChanged to be consistent
-    connect(this,
-            SIGNAL(connectedChanged()),
-            SIGNAL(statusChanged()));
-    connect(this,
-            SIGNAL(connectedChanged()),
-            SIGNAL(statusMessageChanged()));
-
-    // and make sure it is enabled and connected
-    if (!mAccount->isEnabled()) {
-        QTimer::singleShot(0, this, SLOT(ensureEnabled()));
-    } else {
-        QTimer::singleShot(0, this, SLOT(ensureConnected()));
-    }
     Q_EMIT accountIdChanged();
-}
-
-void AccountEntry::ensureEnabled()
-{
-    mAccount->setConnectsAutomatically(true);
-    connect(mAccount->setEnabled(true),
-            SIGNAL(finished(Tp::PendingOperation*)),
-            SLOT(ensureConnected()));
-}
-
-void AccountEntry::ensureConnected()
-{
-    // if the account is not connected, request it to connect
-    if (!mAccount->connection() || mAccount->connectionStatus() == Tp::ConnectionStatusDisconnected) {
-        Tp::Presence presence(Tp::ConnectionPresenceTypeAvailable, "available", "online");
-        mAccount->setRequestedPresence(presence);
-    } else {
-        onConnectionChanged();
-    }
-
+    
+    // we have to postpone this call to give telepathyhelper time to connect the signals
+    QMetaObject::invokeMethod(this, "onConnectionChanged", Qt::QueuedConnection, Q_ARG(Tp::ConnectionPtr, mAccount->connection()));
+    QMetaObject::invokeMethod(this, "accountReady", Qt::QueuedConnection);
     mReady = true;
-    Q_EMIT accountReady();
 }
 
 void AccountEntry::watchSelfContactPresence()
@@ -208,7 +176,20 @@
 
     connect(mAccount->connection()->selfContact().data(),
             SIGNAL(presenceChanged(Tp::Presence)),
+            SIGNAL(statusChanged()));
+
+    connect(mAccount->connection()->selfContact().data(),
+            SIGNAL(presenceChanged(Tp::Presence)),
+            SIGNAL(statusMessageChanged()));
+
+    connect(mAccount->connection()->selfContact().data(),
+            SIGNAL(presenceChanged(Tp::Presence)),
+            SIGNAL(activeChanged()));
+
+    connect(mAccount->connection()->selfContact().data(),
+            SIGNAL(presenceChanged(Tp::Presence)),
             SIGNAL(connectedChanged()));
+
 }
 
 void AccountEntry::onSelfHandleChanged(uint handle)
@@ -220,20 +201,20 @@
     Q_EMIT selfContactIdChanged();
 }
 
-void AccountEntry::onConnectionChanged()
+void AccountEntry::onConnectionChanged(Tp::ConnectionPtr connection)
 {
-    if (!mAccount->connection()) {
-        // ensure the account gets connected
-        ensureConnected();
-    } else {
-        mConnectionInfo.busName = mAccount->connection()->busName();
-        mConnectionInfo.objectPath = mAccount->connection()->objectPath();
+    if (!connection.isNull()) {
+        mConnectionInfo.busName = connection->busName();
+        mConnectionInfo.objectPath = connection->objectPath();
 
-        connect(mAccount->connection().data(),
+        connect(connection.data(),
                 SIGNAL(selfHandleChanged(uint)),
                 SLOT(onSelfHandleChanged(uint)));
 
         watchSelfContactPresence();
+    } else {
+        mConnectionInfo.busName = QString();
+        mConnectionInfo.objectPath = QString();
     }
 
     Q_EMIT connectedChanged();

=== modified file 'libtelephonyservice/accountentry.h'
--- libtelephonyservice/accountentry.h	2015-06-11 16:48:18 +0000
+++ libtelephonyservice/accountentry.h	2015-06-24 17:27:35 +0000
@@ -57,19 +57,18 @@
 
     bool ready() const;
     QString accountId() const;
-    bool active() const;
     QString displayName() const;
     QString status() const;
     QString statusMessage() const;
     QString selfContactId() const;
     void setDisplayName(const QString &name);
-    virtual bool connected() const;
     Tp::AccountPtr account() const;
     virtual AccountType type() const;
     virtual QStringList addressableVCardFields() const;
-
     virtual bool compareIds(const QString &first, const QString &second) const;
-
+    virtual bool active() const;
+    virtual bool connected() const;
+ 
     Protocol *protocolInfo() const;
 
 Q_SIGNALS:
@@ -83,13 +82,12 @@
     void connectedChanged();
     void addressableVCardFieldsChanged();
     void removed();
+    void connectionStatusChanged(Tp::ConnectionStatus status);
 
 protected Q_SLOTS:
     virtual void initialize();
-    virtual void ensureEnabled();
-    virtual void ensureConnected();
     virtual void watchSelfContactPresence();
-    virtual void onConnectionChanged();
+    virtual void onConnectionChanged(Tp::ConnectionPtr connection);
     virtual void onSelfHandleChanged(uint handle);
 
 protected:

=== modified file 'libtelephonyservice/chatmanager.cpp'
--- libtelephonyservice/chatmanager.cpp	2015-03-10 21:41:45 +0000
+++ libtelephonyservice/chatmanager.cpp	2015-06-24 17:27:35 +0000
@@ -55,12 +55,12 @@
     mMessagesAckTimer.setInterval(1000);
     mMessagesAckTimer.setSingleShot(true);
     connect(&mMessagesAckTimer, SIGNAL(timeout()), SLOT(onAckTimerTriggered()));
-    connect(TelepathyHelper::instance(), SIGNAL(connectedChanged()), SLOT(onConnectedChanged()));
+    connect(TelepathyHelper::instance(), SIGNAL(setupReady()), SLOT(onConnectedChanged()));
 }
 
 void ChatManager::onConnectedChanged()
 {
-    if (TelepathyHelper::instance()->connected()) {
+    if (TelepathyHelper::instance()->ready()) {
         onAckTimerTriggered();
     }
 }

=== modified file 'libtelephonyservice/multimediaaccountentry.cpp'
--- libtelephonyservice/multimediaaccountentry.cpp	2015-06-05 20:36:01 +0000
+++ libtelephonyservice/multimediaaccountentry.cpp	2015-06-24 17:27:35 +0000
@@ -51,8 +51,8 @@
     return mAccount->protocolInfo().addressableVCardFields();
 }
 
-void MultimediaAccountEntry::onConnectionChanged()
+void MultimediaAccountEntry::onConnectionChanged(Tp::ConnectionPtr connection)
 {
     // make sure the generic code is also run
-    AccountEntry::onConnectionChanged();
+    AccountEntry::onConnectionChanged(connection);
 }

=== modified file 'libtelephonyservice/multimediaaccountentry.h'
--- libtelephonyservice/multimediaaccountentry.h	2015-06-05 20:36:01 +0000
+++ libtelephonyservice/multimediaaccountentry.h	2015-06-24 17:27:35 +0000
@@ -39,7 +39,7 @@
 
 private Q_SLOTS:
     // reimplemented from AccountEntry
-    void onConnectionChanged();
+    void onConnectionChanged(Tp::ConnectionPtr connection);
 
 protected:
     explicit MultimediaAccountEntry(const Tp::AccountPtr &account, QObject *parent = 0);

=== modified file 'libtelephonyservice/ofonoaccountentry.cpp'
--- libtelephonyservice/ofonoaccountentry.cpp	2015-05-11 13:16:25 +0000
+++ libtelephonyservice/ofonoaccountentry.cpp	2015-06-24 17:27:35 +0000
@@ -102,6 +102,14 @@
     return AccountEntry::PhoneAccount;
 }
 
+bool OfonoAccountEntry::active() const
+{
+    return (!mAccount.isNull() &&
+            !mAccount->connection().isNull() &&
+            !mAccount->connection()->selfContact().isNull() &&
+             mAccount->connection()->selfContact()->presence().type() != Tp::ConnectionPresenceTypeOffline);
+}
+
 bool OfonoAccountEntry::connected() const
 {
     return !mAccount.isNull() && !mAccount->connection().isNull() &&
@@ -143,19 +151,31 @@
     Q_EMIT voicemailIndicatorChanged();
 }
 
-void OfonoAccountEntry::onConnectionChanged()
+void OfonoAccountEntry::onConnectionChanged(Tp::ConnectionPtr connection)
 {
     // make sure the generic code is also run
-    AccountEntry::onConnectionChanged();
+    AccountEntry::onConnectionChanged(connection);
 
     QDBusConnection dbusConnection = QDBusConnection::sessionBus();
 
-    if (!mAccount->connection()) {
+    if (!connection) {
         // disconnect any previous dbus connections
         if (!mConnectionInfo.objectPath.isEmpty()) {
             dbusConnection.disconnect(mConnectionInfo.busName, mConnectionInfo.objectPath,
                                       CANONICAL_TELEPHONY_EMERGENCYMODE_IFACE, "EmergencyNumbersChanged",
                                       this, SLOT(onEmergencyNumbersChanged(QStringList)));
+            // connect the voicemail number changed signal
+            dbusConnection.disconnect(mConnectionInfo.busName, mConnectionInfo.objectPath,
+                                      CANONICAL_TELEPHONY_VOICEMAIL_IFACE, "VoicemailNumberChanged",
+                                      this, SLOT(onVoicemailNumberChanged(QString)));
+
+            dbusConnection.disconnect(mConnectionInfo.busName, mConnectionInfo.objectPath,
+                                      CANONICAL_TELEPHONY_VOICEMAIL_IFACE, "VoicemailCountChanged",
+                                      this, SLOT(onVoicemailCountChanged(uint)));
+
+            dbusConnection.disconnect(mConnectionInfo.busName, mConnectionInfo.objectPath,
+                                      CANONICAL_TELEPHONY_VOICEMAIL_IFACE, "VoicemailIndicatorChanged",
+                                      this, SLOT(onVoicemailIndicatorChanged(bool)));
         }
     } else {
         // connect the emergency numbers changed signal
@@ -168,7 +188,9 @@
         QDBusReply<QStringList> replyNumbers = connIface.call("EmergencyNumbers");
         if (replyNumbers.isValid()) {
             mEmergencyNumbers = replyNumbers.value();
-            Q_EMIT emergencyNumbersChanged();
+            if (mReady) {
+                Q_EMIT emergencyNumbersChanged();
+            }
         }
 
         // connect the voicemail number changed signal
@@ -180,7 +202,9 @@
         QDBusReply<QString> replyNumber = voicemailIface.call("VoicemailNumber");
         if (replyNumber.isValid()) {
             mVoicemailNumber = replyNumber.value();
-            Q_EMIT voicemailNumberChanged();
+            if (mReady) {
+                Q_EMIT voicemailNumberChanged();
+            }
         } else {
             qWarning() << "Could not get voicemail number!";
         }
@@ -193,7 +217,9 @@
         QDBusReply<uint> replyCount = voicemailIface.call("VoicemailCount");
         if (replyCount.isValid()) {
             mVoicemailCount = replyCount.value();
-            Q_EMIT voicemailCountChanged();
+            if (mReady) {
+                Q_EMIT voicemailCountChanged();
+            }
         }
 
         // connect the voicemail indicator changed signal
@@ -204,13 +230,16 @@
         QDBusReply<bool> replyIndicator = voicemailIface.call("VoicemailIndicator");
         if (replyIndicator.isValid()) {
             mVoicemailIndicator = replyIndicator.value();
-            Q_EMIT voicemailIndicatorChanged();
+            if (mReady) {
+                Q_EMIT voicemailIndicatorChanged();
+            }
         }
 
         // and get the serial
         QDBusInterface ussdIface(mConnectionInfo.busName, mConnectionInfo.objectPath, CANONICAL_TELEPHONY_USSD_IFACE);
         mSerial = ussdIface.property("Serial").toString();
+        if (mReady) {
+            Q_EMIT serialChanged();
+        }
     }
-
-    Q_EMIT serialChanged();
 }

=== modified file 'libtelephonyservice/ofonoaccountentry.h'
--- libtelephonyservice/ofonoaccountentry.h	2015-04-16 22:26:23 +0000
+++ libtelephonyservice/ofonoaccountentry.h	2015-06-24 17:27:35 +0000
@@ -53,6 +53,7 @@
     // reimplemented from AccountEntry
     virtual AccountEntry::AccountType type() const;
     virtual bool connected() const;
+    virtual bool active() const;
     virtual bool compareIds(const QString &first, const QString &second) const;
     virtual QStringList addressableVCardFields();
 
@@ -73,7 +74,7 @@
     void onVoicemailIndicatorChanged(bool visible);
 
     // reimplemented from AccountEntry
-    void onConnectionChanged();
+    void onConnectionChanged(Tp::ConnectionPtr connection);
 
 protected:
     explicit OfonoAccountEntry(const Tp::AccountPtr &account, QObject *parent = 0);

=== modified file 'libtelephonyservice/telepathyhelper.cpp'
--- libtelephonyservice/telepathyhelper.cpp	2015-06-11 16:48:18 +0000
+++ libtelephonyservice/telepathyhelper.cpp	2015-06-24 17:27:35 +0000
@@ -45,11 +45,11 @@
 
 TelepathyHelper::TelepathyHelper(QObject *parent)
     : QObject(parent),
+      mPendingAccountReady(0),
       mDefaultCallAccount(NULL),
       mDefaultMessagingAccount(NULL),
       mChannelObserver(0),
-      mFirstTime(true),
-      mConnected(false),
+      mReady(false),
       mHandlerInterface(0),
       mPhoneSettings(new QGSettings("com.ubuntu.phone")),
       mApproverInterface(0),
@@ -86,7 +86,6 @@
             SLOT(onAccountManagerReady(Tp::PendingOperation*)));
 
     mClientRegistrar = Tp::ClientRegistrar::create(mAccountManager);
-    connect(this, SIGNAL(accountReady()), SIGNAL(setupReady()));
     connect(mPhoneSettings, SIGNAL(changed(QString)), this, SLOT(onSettingsChanged(QString)));
     connect(&mFlightModeInterface, SIGNAL(FlightModeChanged(bool)), this, SIGNAL(flightModeChanged()));
 
@@ -220,22 +219,21 @@
     return mApproverInterface;
 }
 
-bool TelepathyHelper::connected() const
+bool TelepathyHelper::ready() const
 {
     if (QCoreApplication::applicationName() != "telephony-service-handler" &&
         mAccounts.isEmpty() &&
         !GreeterContacts::instance()->isGreeterMode()) {
         // get the status from the handler
-        QDBusReply<bool> reply = handlerInterface()->call("IsConnected");
+        QDBusReply<bool> reply = handlerInterface()->call("IsReady");
         if (reply.isValid()) {
             return reply.value();
         }
     }
 
-    return mConnected;
+    return mReady;
 }
 
-
 void TelepathyHelper::registerChannelObserver(const QString &observerName)
 {
     QString name = observerName;
@@ -274,9 +272,6 @@
 {
     connect(entry,
             SIGNAL(connectedChanged()),
-            SLOT(updateConnectedStatus()));
-    connect(entry,
-            SIGNAL(connectedChanged()),
             SIGNAL(activeAccountsChanged()));
     connect(entry,
             SIGNAL(accountReady()),
@@ -406,8 +401,6 @@
     }
     mAccounts.removeAll(account);
 
-    updateConnectedStatus();
-
     Q_EMIT accountIdsChanged();
     Q_EMIT accountsChanged();
     Q_EMIT phoneAccountsChanged();
@@ -434,8 +427,6 @@
     }
     mAccounts = QList<AccountEntry*>() << sortedOfonoAccounts.values() <<  sortedOtherAccounts.values() ;
 
-    updateConnectedStatus();
-
     Q_EMIT accountIdsChanged();
     Q_EMIT accountsChanged();
     Q_EMIT phoneAccountsChanged();
@@ -465,13 +456,15 @@
         }
     }
 
-    if (mAccounts.count() == 0) {
+    // get the number of pending accounts to be processed first
+    mPendingAccountReady = mAccounts.count();
+
+    if (mPendingAccountReady == 0) {
+        mReady = true;
         Q_EMIT setupReady();
         return;
     }
 
-    updateConnectedStatus();
-
     Q_EMIT accountIdsChanged();
     Q_EMIT accountsChanged();
     Q_EMIT phoneAccountsChanged();
@@ -482,29 +475,15 @@
 
 void TelepathyHelper::onAccountReady()
 {
-    if (mFirstTime) {
-        Q_EMIT accountReady();
-    }
-
-    mFirstTime = false;
-}
-
-void TelepathyHelper::updateConnectedStatus()
-{
-    bool previousConnectedStatus = mConnected;
-    mConnected = false;
-
-    // check if any of the accounts is currently connected
-    Q_FOREACH(AccountEntry *account, mAccounts) {
-        if (account->connected()) {
-            mConnected = true;
-            break;
-        }
-    }
-
-    // avoid emitting changed signals when the pro
-    if (mConnected != previousConnectedStatus) {
-        Q_EMIT connectedChanged();
+    if (mReady) {
+        return;
+    }
+
+    mPendingAccountReady--;
+
+    if (mPendingAccountReady == 0) {
+        mReady = true;
+        Q_EMIT setupReady();
     }
 }
 

=== modified file 'libtelephonyservice/telepathyhelper.h'
--- libtelephonyservice/telepathyhelper.h	2015-06-10 21:05:50 +0000
+++ libtelephonyservice/telepathyhelper.h	2015-06-24 17:27:35 +0000
@@ -45,7 +45,7 @@
 class TelepathyHelper : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(bool connected READ connected NOTIFY connectedChanged)
+    Q_PROPERTY(bool ready READ ready NOTIFY setupReady)
     Q_PROPERTY(QStringList accountIds READ accountIds NOTIFY accountIdsChanged)
     Q_PROPERTY(QQmlListProperty<AccountEntry> accounts READ qmlAccounts NOTIFY accountsChanged)
     Q_PROPERTY(QQmlListProperty<AccountEntry> phoneAccounts READ qmlPhoneAccounts NOTIFY phoneAccountsChanged)
@@ -81,7 +81,7 @@
     void setMmsGroupChat(bool value);
     bool flightMode();
     void setFlightMode(bool value);
-    bool connected() const;
+    bool ready() const;
     QStringList accountIds();
     AccountEntry *accountForConnection(const Tp::ConnectionPtr &connection) const;
     Q_INVOKABLE AccountEntry *accountForId(const QString &accountId) const;
@@ -106,8 +106,6 @@
 Q_SIGNALS:
     void channelObserverCreated(ChannelObserver *observer);
     void channelObserverUnregistered();
-    void accountReady();
-    void connectedChanged();
     void accountIdsChanged();
     void accountsChanged();
     void accountAdded(AccountEntry *account);
@@ -132,7 +130,6 @@
     void onAccountReady();
     void onNewAccount(const Tp::AccountPtr &account);
     void onAccountRemoved();
-    void updateConnectedStatus();
     void onSettingsChanged(const QString&);
 
 private:
@@ -144,11 +141,11 @@
     Tp::Features mConnectionFeatures;
     Tp::ClientRegistrarPtr mClientRegistrar;
     QList<AccountEntry*> mAccounts;
+    int mPendingAccountReady;
     AccountEntry *mDefaultCallAccount;
     AccountEntry *mDefaultMessagingAccount;
     ChannelObserver *mChannelObserver;
-    bool mFirstTime;
-    bool mConnected;
+    bool mReady;
     bool mMmsGroupChat;
     mutable QDBusInterface *mHandlerInterface;
     QGSettings *mPhoneSettings;

=== modified file 'tests/common/telepathytest.cpp'
--- tests/common/telepathytest.cpp	2015-06-05 18:42:14 +0000
+++ tests/common/telepathytest.cpp	2015-06-24 17:27:35 +0000
@@ -95,6 +95,9 @@
         }
 
         account = pa->account();
+        // on the real device this is done by the telepathy-ofono plugin
+        account->setEnabled(true);
+        account->setConnectsAutomatically(true);
         finished = true;
     });
 

=== modified file 'tests/libtelephonyservice/AccountEntryTest.cpp'
--- tests/libtelephonyservice/AccountEntryTest.cpp	2015-05-08 21:57:06 +0000
+++ tests/libtelephonyservice/AccountEntryTest.cpp	2015-06-24 17:27:35 +0000
@@ -181,7 +181,8 @@
     QVERIFY(mAccount->connected());
 
     // now set the account offline and see if the active flag changes correctly
-    mMockController->SetPresence("away", "away");
+    //mMockController->SetPresence("offline", "offline");
+    mAccount->account()->reconnect();
     TRY_VERIFY(connectedChangedSpy.count() > 0);
     TRY_VERIFY(!mAccount->connected());
 

=== modified file 'tests/libtelephonyservice/OfonoAccountEntryTest.cpp'
--- tests/libtelephonyservice/OfonoAccountEntryTest.cpp	2015-05-08 21:57:06 +0000
+++ tests/libtelephonyservice/OfonoAccountEntryTest.cpp	2015-06-24 17:27:35 +0000
@@ -97,13 +97,13 @@
     QSignalSpy connectedChangedSpy(mAccount, SIGNAL(connectedChanged()));
 
     // now set the account offline and see if the active flag changes correctly
-    mMockController->SetPresence("away", "away");
+    mMockController->SetOnline(false);
     TRY_VERIFY(connectedChangedSpy.count() > 0);
     TRY_VERIFY(!mAccount->connected());
 
     // now re-enable the account and check that the entry is updated
     connectedChangedSpy.clear();
-    mMockController->SetPresence("available", "online");
+    mMockController->SetOnline(true);
     // because of the way the mock was implemented, sometimes this can return two connectedChanged() signals.
     TRY_VERIFY(connectedChangedSpy.count() > 0);
     TRY_VERIFY(mAccount->connected());
@@ -131,11 +131,11 @@
 
 void OfonoAccountEntryTest::testEmergencyNumbers()
 {
+    // check that the list is not empty at startup
+    QTRY_VERIFY(!mAccount->emergencyNumbers().isEmpty());
+
     QSignalSpy emergencyNumbersChangedSpy(mAccount, SIGNAL(emergencyNumbersChanged()));
 
-    // check that the list is not empty at startup
-    QVERIFY(!mAccount->emergencyNumbers().isEmpty());
-
     QStringList numbers;
     numbers << "111" << "190" << "911";
     qSort(numbers);

=== modified file 'tests/libtelephonyservice/TelepathyHelperTest.cpp'
--- tests/libtelephonyservice/TelepathyHelperTest.cpp	2015-06-08 18:28:50 +0000
+++ tests/libtelephonyservice/TelepathyHelperTest.cpp	2015-06-24 17:27:35 +0000
@@ -37,7 +37,6 @@
     void initTestCase();
     void init();
     void cleanup();
-    void testConnected();
     void testAccounts();
     void testPhoneAccounts();
     void testAccountSorting();
@@ -90,38 +89,6 @@
     mPhoneController->deleteLater();
 }
 
-void TelepathyHelperTest::testConnected()
-{
-    QSignalSpy connectedChangedSpy(TelepathyHelper::instance(), SIGNAL(connectedChanged()));
-
-    // check that the default status is connected (always true for mock accounts)
-    QVERIFY(TelepathyHelper::instance()->connected());
-
-    // set one of the accounts offline and check that the connected status stays true
-    mGenericController->SetOnline(false);
-    QTest::qWait(1000);
-    QCOMPARE(connectedChangedSpy.count(), 0);
-    QVERIFY(TelepathyHelper::instance()->connected());
-
-    // and set the other account as offline too. This time connected needs to change to false
-    mPhoneController->SetOnline(false);
-    TRY_COMPARE(connectedChangedSpy.count(), 1);
-    QVERIFY(!TelepathyHelper::instance()->connected());
-
-    // now set one of the accounts back online
-    connectedChangedSpy.clear();
-    mPhoneController->SetOnline(true);
-    TRY_COMPARE(connectedChangedSpy.count(), 1);
-    QVERIFY(TelepathyHelper::instance()->connected());
-
-    // and the other one just in case
-    connectedChangedSpy.clear();
-    mGenericController->SetOnline(true);
-    QTest::qWait(1000);
-    QCOMPARE(connectedChangedSpy.count(), 0);
-    QVERIFY(TelepathyHelper::instance()->connected());
-}
-
 void TelepathyHelperTest::testAccounts()
 {
     QCOMPARE(TelepathyHelper::instance()->accounts().count(), 2);

